@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2022 Roberto Alsina and others.
+# Copyright © 2012-2023 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -669,11 +669,9 @@ def html_tostring_fragment(document):
     for start in start_fragments:
         if doc.startswith(start):
             doc = doc[len(start):].strip()
-            print(repr(doc))
     for end in end_fragments:
         if doc.endswith(end):
             doc = doc[:-len(end)].strip()
-            print(repr(doc))
     return doc
 
 
@@ -731,7 +729,7 @@ def load_messages(themes, translations, default_lang, themes_dirs):
                 del translation
             except ImportError as orig:
                 last_exception = orig
-        del(english)
+        del english
         sys.path = oldpath
 
     if not all(found.values()):
